import type Fetch from 'ahooks/lib/useRequest/src/Fetch';
import type { Options } from 'ahooks/lib/useRequest/src/types';
export declare enum ApiMethod {
    Get = 0,
    Post = 1,
    Patch = 2,
    Delete = 3
}
export interface ApiRule<Code = any> {
    code: Code;
    method: ApiMethod;
    path: string;
    service?: string | boolean;
    axios?: any;
    ahooks?: any;
    mock?: (<T = any, V = any>(input?: T) => Promise<ResponseData<V>> | any);
}
export interface PageInfo {
    pageNumber: number;
    pageSize: number;
    total?: number;
}
export interface PageQuery<T> {
    pageInfo: PageInfo;
    query: T;
}
export interface PageData<T> {
    pageInfo: PageInfo;
    data: T[];
}
export interface ResponseData<T = any> {
    code: string;
    message: string;
    pageInfo?: PageInfo;
    data: T;
    error?: ApiError;
}
export type FetchApi<T, V = any> = {
    (input?: T): Promise<ResponseData<V>>;
    safe(input?: T): Promise<ResponseData<V>>;
};
export declare enum ApiChannel {
    AuthChannel = 0,
    PublicChannel = 1
}
export interface ApiRequestConfig<T> {
    rule: ApiRule<T>;
    channel: ApiChannel;
}
export interface Result<TData, TParams extends any[]> {
    loading: boolean;
    data: TData;
    error?: Error;
    params: TParams | [];
    cancel: Fetch<TData, TParams>['cancel'];
    refresh: Fetch<TData, TParams>['refresh'];
    refreshAsync: Fetch<TData, TParams>['refreshAsync'];
    run: Fetch<TData, TParams>['run'];
    runAsync: Fetch<TData, TParams>['runAsync'];
    mutate: Fetch<TData, TParams>['mutate'];
}
export interface HookResult<TData, TParams extends any[]> extends Result<ResponseData<TData>, TParams> {
}
export type HookApi<T, V = any> = (options?: Options<V, T[]>) => HookResult<V, T[]>;
export declare class ApiError extends Error {
    code: string | undefined;
    constructor(message: string, code: string | undefined);
}
